@@ -33,7 +33,7 @@
 #include "logs.h"
 
 
-#define SQL_BUFFER 4096
+#define SQL_BUFFER 8192
 
 typedef struct stmt_list_s {
   const char   *sql;
@@ -116,10 +116,6 @@ typedef enum database_stmt {
   STMT_DELETE_ASSOC_FILE_GRABBER,
   STMT_DELETE_DLCONTEXT,
 
-  STMT_SELECT_INFO_VALUE,
-  STMT_INSERT_INFO,
-  STMT_UPDATE_INFO,
-
   STMT_CLEANUP_ASSOC_FILE_METADATA,
   STMT_CLEANUP_ASSOC_FILE_GRABBER,
   STMT_CLEANUP_META,
@@ -164,10 +160,6 @@ static const stmt_list_t g_stmts[] = {
   [STMT_DELETE_ASSOC_FILE_GRABBER]   = { DELETE_ASSOC_FILE_GRABBER,   NULL },
   [STMT_DELETE_DLCONTEXT]            = { DELETE_DLCONTEXT,            NULL },
 
-  [STMT_SELECT_INFO_VALUE]           = { SELECT_INFO_VALUE,           NULL },
-  [STMT_INSERT_INFO]                 = { INSERT_INFO,                 NULL },
-  [STMT_UPDATE_INFO]                 = { UPDATE_INFO,                 NULL },
-
   [STMT_CLEANUP_ASSOC_FILE_METADATA] = { CLEANUP_ASSOC_FILE_METADATA, NULL },
   [STMT_CLEANUP_ASSOC_FILE_GRABBER]  = { CLEANUP_ASSOC_FILE_GRABBER,  NULL },
   [STMT_CLEANUP_META]                = { CLEANUP_META,                NULL },
@@ -182,7 +174,7 @@ static const stmt_list_t g_stmts[] = {
   [STMT_END_TRANSACTION]             = { END_TRANSACTION,             NULL },
 };
 
-#define STMT_GET(id) database->stmts[id].stmt
+#define STMT_GET(id) database->stmts ? database->stmts[id].stmt : NULL
 
 #define VH_DB_BIND_TEXT_OR_GOTO(stmt, col, value, label)            \
   do                                                                \
@@ -1025,9 +1017,13 @@ database_info_get (database_t *database, const char *name)
 {
   char *ret = NULL;
   int res, err = -1;
-  sqlite3_stmt *stmt = STMT_GET (STMT_SELECT_INFO_VALUE);
+  sqlite3_stmt *stmt;
 
-  VH_DB_BIND_TEXT_OR_GOTO (stmt, 1, name, out);
+  res = sqlite3_prepare_v2 (database->db, SELECT_INFO_VALUE, -1, &stmt, NULL);
+  if (res != SQLITE_OK)
+    goto out_err;
+
+  VH_DB_BIND_TEXT_OR_GOTO (stmt, 1, name, out_free);
 
   res = sqlite3_step (stmt);
   if (res == SQLITE_ROW)
@@ -1040,8 +1036,9 @@ database_info_get (database_t *database, const char *name)
   sqlite3_clear_bindings (stmt);
   err = 0;
 
- out:
-  sqlite3_reset (stmt);
+ out_free:
+  sqlite3_finalize (stmt);
+ out_err:
   if (err < 0)
     valhalla_log (VALHALLA_MSG_ERROR, "%s", sqlite3_errmsg (database->db));
   return ret;
@@ -1051,19 +1048,22 @@ static void
 database_info_insert (database_t *database, const char *name, const char *value)
 {
   int res, err = -1;
-  sqlite3_stmt *stmt = STMT_GET (STMT_INSERT_INFO);
+  sqlite3_stmt *stmt;
 
-  VH_DB_BIND_TEXT_OR_GOTO (stmt, 1, name,  out_reset);
-  VH_DB_BIND_TEXT_OR_GOTO (stmt, 2, value, out_clear);
+  res = sqlite3_prepare_v2 (database->db, INSERT_INFO, -1, &stmt, NULL);
+  if (res != SQLITE_OK)
+    goto out_err;
+
+  VH_DB_BIND_TEXT_OR_GOTO (stmt, 1, name,  out_free);
+  VH_DB_BIND_TEXT_OR_GOTO (stmt, 2, value, out_free);
 
   res = sqlite3_step (stmt);
   if (res == SQLITE_DONE)
     err = 0;
 
- out_clear:
-  sqlite3_clear_bindings (stmt);
- out_reset:
-  sqlite3_reset (stmt);
+ out_free:
+  sqlite3_finalize (stmt);
+ out_err:
   if (err < 0)
     valhalla_log (VALHALLA_MSG_ERROR, "%s", sqlite3_errmsg (database->db));
 }
@@ -1240,12 +1240,13 @@ vh_database_uninit (database_t *database)
   if (database->path)
     free (database->path);
 
-  for (i = 0; i < ARRAY_NB_ELEMENTS (g_stmts); i++)
-    if (STMT_GET (i))
-      sqlite3_finalize (STMT_GET (i));
-
   if (database->stmts)
+  {
+    for (i = 0; i < ARRAY_NB_ELEMENTS (g_stmts); i++)
+      if (STMT_GET (i))
+        sqlite3_finalize (STMT_GET (i));
     free (database->stmts);
+  }
 
   if (database->file_type)
     free (database->file_type);
@@ -1261,7 +1262,7 @@ vh_database_uninit (database_t *database)
 database_t *
 vh_database_init (const char *path)
 {
-  int res;
+  int res, exists;
   unsigned int i;
   database_t *database;
 
@@ -1283,6 +1284,8 @@ vh_database_init (const char *path)
   if (res != SQLITE_OK)
     return NULL;
 
+  exists = vh_file_exists (path);
+
   res = sqlite3_open (path, &database->db);
   if (res)
   {
@@ -1292,14 +1295,17 @@ vh_database_init (const char *path)
   }
 
   database->path = strdup (path);
+
+  if (exists && database_info (database))
+    goto err;
+
   database_create_table (database);
 
   res = database_prepare_stmt (database);
   if (res)
     goto err;
 
-  res = database_info (database);
-  if (res)
+  if (!exists && database_info (database))
     goto err;
 
   database->file_type = malloc (sizeof (g_file_type));
@@ -1330,14 +1336,14 @@ vh_database_init (const char *path)
 /*                                                                            */
 /******************************************************************************/
 
-#define SQL_CONCAT(sql, str, args...)             \
-  do                                              \
-  {                                               \
-    char buf[256];                                \
-    snprintf (buf, sizeof (buf), str, ##args);    \
-    if (strlen (sql) + strlen (buf) < SQL_BUFFER) \
-      strcat (sql, buf);                          \
-  }                                               \
+#define SQL_CONCAT(sql, str, args...)                   \
+  do                                                    \
+  {                                                     \
+    char buf[256];                                      \
+    sqlite3_snprintf (sizeof (buf), buf, str, ##args);  \
+    if (strlen (sql) + strlen (buf) < SQL_BUFFER)       \
+      strcat (sql, buf);                                \
+  }                                                     \
   while (0)
 
 #define SQL_CONCAT_TYPE(sql, item, def)                              \
