@@ -242,6 +242,10 @@ valhalla_uninit (valhalla_t *handle)
   vh_url_global_uninit ();
 #endif /* USE_GRABBER */
 
+#ifdef USE_LAVC
+  av_lockmgr_register (NULL);
+#endif /* USE_LAVC */
+
   valhalla_log (VALHALLA_MSG_VERBOSE, "%s: end", __FUNCTION__);
 
   free (handle);
@@ -582,6 +586,12 @@ valhalla_db_file_get (valhalla_t *handle,
     vh_dbmanager_db_file_get (handle->dbmanager, id, path, restriction, res);
 }
 
+/******************************************************************************/
+/*                                                                            */
+/*                  For Public Insertions/Updates/Deletions                   */
+/*                                                                            */
+/******************************************************************************/
+
 int
 valhalla_db_metadata_insert (valhalla_t *handle, const char *path,
                              const char *meta, const char *data,
